pub struct Resource<S>where
S: QueueStrategy,{ /* private fields */ }Expand description
Represents a simple resource that gathers its statistics.
Implementations
Sourceimpl<S> Resource<S>where
S: QueueStrategy,
impl<S> Resource<S>where
S: QueueStrategy,
Sourcepub fn new(strategy: S, count: isize) -> NewResource<S>
pub fn new(strategy: S, count: isize) -> NewResource<S>
Create a new resource by the specified queue storage and initial count, where the latter becomes the capacity as well.
Sourcepub fn new_with_max_count(
strategy: S,
count: isize,
max_count: Option<isize>,
) -> NewResource<S>
pub fn new_with_max_count( strategy: S, count: isize, max_count: Option<isize>, ) -> NewResource<S>
Create a new resource by the specified queue storage, initial count and optional maximum count, i.e. capacity.