The Process computation to represent discontinuous processes.
Modules
Structs
- AndThen
- The monadic bind for the
Processcomputation. - Ap
- The function application for the
Processcomputation. - Await
- Await a signal that should be emitted by the specified observable.
- Await
Result - Await a cancellable signal that should be emitted by the specified observable.
- Cancel
- Cancel the current process.
- Cancel
ById - Cancel a process by the specified process identifier.
- Delay
- Allows delaying the
Processcomputation by the specified function. - Embed
Result - Embeds the result value within the
Processcomputation. - Finally
- The finally block for the
Processcomputation. - Hold
- The hold block for the
Processcomputation. - Id
- Return the corresponding process identifier.
- Interrupt
- Interrupt a process with the specified identifier if the process
is held by computation
hold_process. - Interruption
Time - Return the expected interruption time after finishing the
hold_processcomputation, which value may change if the corresponding process is preempted. - IsInterrupted
- Test whether the process with the specified identifier was interrupted.
- IsPassivated
- Test whether the process with the specified identifier was passivated.
- Loop
- Executes the
Processcomputation in loop. - Map
- The functor for the
Processcomputation. - Never
- The process that never returns a result.
- NewProcess
Id - A computation that creates a
ProcessIdvalue. - Panic
- Allows creating the
Processcomputation that panics with the specified message. - Passivate
- Passivate the
Processcomputation. - Passivate
Before - Passivate the
Processcomputation before performing some action. - Process
Box - The
Processcomputation box. - Process
Id - The computation identifier.
- Process
With Priority - Reactivate
- Reactivate the process with the specified identifier.
- Reactivate
Immediately - Reactivate immediately the process with the specified identifier.
- Reactivate
Many Immediately - Reactivate immediately the processes with specified identifiers.
- Return
- Allows creating the
Processcomputation from a pure value. - Run
- Run the computation.
- Sequence
- The sequence of computations.
- Sequence_
- The sequence of computations with ignored result.
- Spawn
- Allows spawning another process bound with the current one.
- Spawn
Using Id - Allows spawning another process bound with the current one.
- Timeout
- Allows running another process within the specified timeout.
- Timeout
Using Id - Allows running another process within the specified timeout by using the given identifier.
- Trace
- Trace the computation.
- Transfer
- Like the GoTo statement it transfers the direction of computation.
- When
Cancelling - Register a handler that will be invoked in case of cancelling the current process.
- Zip
- The zip of two
Processcomputations.
Enums
- Process
Cancellation - It defines how the parent and child computations should be cancelled.
- Process
Event - The event that occurs whithin the
Processcomputation.
Traits
- Into
Process - Allows converting to
Processcomputations. - Process
- The computation based on continuations.
Functions
- cancel_
process - Cancel the current process.
- delay_
process - Delay the
Processcomputation. - embed_
result_ process - Embeds the result value within the current process, which may cancel the process, for example.
- hold_
process - Hold the process for the specified time interval.
- loop_
process - Execute the
Processcomputation in loop. - never_
process - A process that never returns a result.
- panic_
process - Return a
Processcomputation that panics with the specified error message. - passivate_
process - Passivate the process.
- passivate_
process_ before - Passivate the process before performing some action.
- process_
await - Await a signal that should be emitted by the specified observable.
- process_
await_ result - Await a cancellable signal that should be emitted by the specified observable.
- process_
id - Return the corresponding process identifier.
- process_
sequence - Create a sequence of computations.
- process_
sequence_ - Create a sequence of computations, where the result is ignored.
- process_
with_ priority - Proceed with the process that would use the specified time point priority.
- restore_
process_ priority - Wrap the computation so that it would restore its priority.
- return_
process - Return a new
Processcomputation by the specified pure value. - spawn_
process - Spawn the child process. In case of cancelling one of the processes, other process will be cancelled too.
- spawn_
process_ using_ id - Spawn the child process specifying how the child and parent processes should be cancelled in case of need.
- spawn_
process_ using_ id_ with - Spawn the child process specifying how the child and parent processes should be cancelled in case of need.
- spawn_
process_ with - Spawn the child process specifying how the child and parent processes should be cancelled in case of need.
- timeout_
process - Try to run the child process within the specified timeout.
- timeout_
process_ using_ id - Try to run the child process within the specified timeout by using the given identifier.
- trace_
process - Trace the computation.
- transfer_
process - Like the GoTo statement it transfers the direction of computation.
- when_
cancelling_ process - Register a handler that will be invoked in case of cancelling the current process.