pub fn spawn_process_using_id<M>( pid: Grc<ProcessId>, comp: M, ) -> SpawnUsingId<M>where M: Process<Item = ()> + Clone + 'static,
Spawn the child process specifying how the child and parent processes should be cancelled in case of need.